==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/sk-SK/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Tento používateľ sa môže prihlásiť',
    'activated_disabled_help_text' => 'Nemôžete upraviť stav aktivácie pre Váš vlastný účet.',
    'assets_user'       => 'Majetok priradený :name',
    'bulk_update_warn'	=> 'Chystáte sa hromadne upraviť nastavenia :user_count používateľlov. Nezapomeňte, že nie je možné zmeniť svoje nastavenia použitím tohto formuláru a tieto musia byť upravené individuálne.',
    'bulk_update_help'	=> 'Tento formulár umožňuje aktualizovať hromadne viacero používateľov. Vyplňte iba položky, ktoré chces zmeny. Všetky prázdne položky ostanú nezmenené.',
    'current_assets'    => 'Majetky aktuálne priradené tomuto používateľovi',
    'clone'             => 'Duplikovať používateľa',
    'contact_user'      => 'Kontakt na :name',
    'edit'              => 'Upraviť používateľa',
    'filetype_info'     => 'Podporované typy súborov: png, gif, jpg, jpeg, doc, docx, pdf, txt, zip a rar.',
    'history_user'      => 'História pre :name',
    'info'				=> 'Info',
    'restore_user'		=> 'Kliknite sem pre obnovenie.',
    'last_login'        => 'Posledné prihlásenie',
    'ldap_config_text'  => 'Nastavenia LDAP-u sa nachádzajú v menu Administrácia => Nastavenia. Vybraná (voliteľná) lokalita bude nastavená pre všetkých importovaných používateľov.',
    'print_assigned'    => 'Vytlačiť všetky priradené',
    'email_assigned'    => 'Zaslať zoznam aktuálne priradeného majetku',
    'user_notified'     => 'Používateľovi bol zaslaný email so zoznamom aktuálne priradených položiek.',
    'auto_assign_label' => 'Zahrnúť tohto používateľa do automatického priraďovania licencií',
    'auto_assign_help'  => 'Nezaradiť tohto používateľa do automatického priraďovania licencií',
    'software_user'     => 'Software priradený :name',
    'send_email_help'   => 'Pre zaslanie prístupových údajov musíte zadať e-mailovú adresu používateľa. Zaslanie prístupových údajov je možné iba v procese vytvárania nového používateľa. Heslá sú ukladané šifrované, nie je ich možné prečítať po uložení.',
    'view_user'         => 'Zobraziť používateľa :name',
    'usercsv'           => 'CSV súbor',
    'two_factor_admin_optin_help' => 'Vaše súčasné nastavenie administrátora umožňujú selektívne vynútenie dvojfaktorovej autentifikácie.  ',
    'two_factor_enrolled' => '2FA prihlásené zariadenie ',
    'two_factor_active'   => '2FA aktívne ',
    'user_deactivated'  => 'Užívateľ sa nemôže prihlásiť',
    'user_activated'  => 'Užívateľ sa môže prihlásiť',
    'activation_status_warning' => 'Nezmeniť stav aktivácie',
    'group_memberships_helpblock' => 'Iba superadmini môžu upravovať členstvo v skupine.',
    'superadmin_permission_warning' => 'Iba superadmini môžu garantovať superadmin prístup.',
    'admin_permission_warning' => 'Iba používatelia s administrátorskými oprávneniami môžu garantovať administrátorsky prístup.',
    'remove_group_memberships' => 'Odstrániť členstvo v skupine',
    'warning_deletion_information' => 'Chystáte sa prevziať všetky položky od :count používateľov uvedených nižšie. Mena superadmin používateľov sú zobrazené červeným.',
    'update_user_assets_status' => 'Aktualizovať všetky asety pre týchto užívateľov na tento status',
    'checkin_user_properties' => 'Prevziať všetky vlastnosti spojené s týmito používateľmi',
    'remote_label'   => 'Toto je vzdialený používateľ',
    'remote'   => 'Vzdialený',
    'remote_help' => 'Toto môže byť užitočne v prípade ak potrebujete odfiltrovať vzdialených používateľov, ktorí nikdy alebo zriedkavo navštevujú fyzické lokality.',
    'not_remote_label' => 'Toto nie je vzdialený používateľ',
    'vip_label' => 'VIP používateľ',
    'vip_help' => 'Toto môže byť užitočné k označeniu dôležitých osôb vo Vašej organizácií, ku ktorým sa má aplikovať odlišný prístup.',
    'create_user' => 'Pridať používateľa',
    'create_user_page_explanation' => 'Tieto údaje použijete pre prvé prihlásenie na stránku.',
    'email_credentials' => 'Poslať prihlasovacie údaje',
    'email_credentials_text' => 'Odošle moje prihlasovacie údaje na emailovú adresu uvedenú vyššie',
    'next_save_user' => 'Ďalej: Uložiť používateľa',
    'all_assigned_list_generation' => 'Generované dňa:',
    'email_user_creds_on_create' => 'Zaslať tomuto používateľovi prihlasovacie údaje mailom?',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/sk-SK/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Tento používateľ sa môže prihlásiť',
    'activated_disabled_help_text' => 'Nemôžete upraviť stav aktivácie pre Váš vlastný účet.',
    'assets_user'       => 'Majetok priradený :name',
    'bulk_update_warn'	=> 'Chystáte sa hromadne upraviť nastavenia :user_count používateľlov. Nezapomeňte, že nie je možné zmeniť svoje nastavenia použitím tohto formuláru a tieto musia byť upravené individuálne.',
    'bulk_update_help'	=> 'Tento formulár umožňuje aktualizovať hromadne viacero používateľov. Vyplňte iba položky, ktoré chces zmeny. Všetky prázdne položky ostanú nezmenené.',
    'current_assets'    => 'Majetky aktuálne priradené tomuto používateľovi',
    'clone'             => 'Duplikovať používateľa',
    'contact_user'      => 'Kontakt na :name',
    'edit'              => 'Upraviť používateľa',
    'filetype_info'     => 'Podporované typy súborov: png, gif, jpg, jpeg, doc, docx, pdf, txt, zip a rar.',
    'history_user'      => 'História pre :name',
    'info'				=> 'Info',
    'restore_user'		=> 'Kliknite sem pre obnovenie.',
    'last_login'        => 'Posledné prihlásenie',
    'ldap_config_text'  => 'Nastavenia LDAP-u sa nachádzajú v menu Administrácia => Nastavenia. Vybraná (voliteľná) lokalita bude nastavená pre všetkých importovaných používateľov.',
    'print_assigned'    => 'Vytlačiť všetky priradené',
    'email_assigned'    => 'Zaslať zoznam aktuálne priradeného majetku',
    'user_notified'     => 'Používateľovi bol zaslaný email so zoznamom aktuálne priradených položiek.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Zahrnúť tohto používateľa do automatického priraďovania licencií',
    'auto_assign_help'  => 'Nezaradiť tohto používateľa do automatického priraďovania licencií',
    'software_user'     => 'Software priradený :name',
    'send_email_help'   => 'Pre zaslanie prístupových údajov musíte zadať e-mailovú adresu používateľa. Zaslanie prístupových údajov je možné iba v procese vytvárania nového používateľa. Heslá sú ukladané šifrované, nie je ich možné prečítať po uložení.',
    'view_user'         => 'Zobraziť používateľa :name',
    'usercsv'           => 'CSV súbor',
    'two_factor_admin_optin_help' => 'Vaše súčasné nastavenie administrátora umožňujú selektívne vynútenie dvojfaktorovej autentifikácie.  ',
    'two_factor_enrolled' => '2FA prihlásené zariadenie ',
    'two_factor_active'   => '2FA aktívne ',
    'user_deactivated'  => 'Užívateľ sa nemôže prihlásiť',
    'user_activated'  => 'Užívateľ sa môže prihlásiť',
    'activation_status_warning' => 'Nezmeniť stav aktivácie',
    'group_memberships_helpblock' => 'Iba superadmini môžu upravovať členstvo v skupine.',
    'superadmin_permission_warning' => 'Iba superadmini môžu garantovať superadmin prístup.',
    'admin_permission_warning' => 'Iba používatelia s administrátorskými oprávneniami môžu garantovať administrátorsky prístup.',
    'remove_group_memberships' => 'Odstrániť členstvo v skupine',
    'warning_deletion_information' => 'Chystáte sa prevziať všetky položky od :count používateľov uvedených nižšie. Mena superadmin používateľov sú zobrazené červeným.',
    'update_user_assets_status' => 'Aktualizovať všetky asety pre týchto užívateľov na tento status',
    'checkin_user_properties' => 'Prevziať všetky vlastnosti spojené s týmito používateľmi',
    'remote_label'   => 'Toto je vzdialený používateľ',
    'remote'   => 'Vzdialený',
    'remote_help' => 'Toto môže byť užitočne v prípade ak potrebujete odfiltrovať vzdialených používateľov, ktorí nikdy alebo zriedkavo navštevujú fyzické lokality.',
    'not_remote_label' => 'Toto nie je vzdialený používateľ',
    'vip_label' => 'VIP používateľ',
    'vip_help' => 'Toto môže byť užitočné k označeniu dôležitých osôb vo Vašej organizácií, ku ktorým sa má aplikovať odlišný prístup.',
    'create_user' => 'Pridať používateľa',
    'create_user_page_explanation' => 'Tieto údaje použijete pre prvé prihlásenie na stránku.',
    'email_credentials' => 'Poslať prihlasovacie údaje',
    'email_credentials_text' => 'Odošle moje prihlasovacie údaje na emailovú adresu uvedenú vyššie',
    'next_save_user' => 'Ďalej: Uložiť používateľa',
    'all_assigned_list_generation' => 'Generované dňa:',
    'email_user_creds_on_create' => 'Zaslať tomuto používateľovi prihlasovacie údaje mailom?',
];
